Try again to fix Windows build of previous.
[libdcp.git] / src / cpl.h
index 952847fe9b6fdf32afb51ef690fb711a4106ad00..8095108860847d29592d0d915d19a82e94078239 100644 (file)
--- a/src/cpl.h
+++ b/src/cpl.h
@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2014 Carl Hetherington <cth@carlh.net>
+    Copyright (C) 2014-2019 Carl Hetherington <cth@carlh.net>
 
     This file is part of libdcp.
 
 
     You should have received a copy of the GNU General Public License
     along with libdcp.  If not, see <http://www.gnu.org/licenses/>.
+
+    In addition, as a special exception, the copyright holders give
+    permission to link the code of portions of this program with the
+    OpenSSL library under certain conditions as described in each
+    individual source file, and distribute linked combinations
+    including the two.
+
+    You must obey the GNU General Public License in all respects
+    for all of the code used other than OpenSSL.  If you modify
+    file(s) with this exception, you may extend this exception to your
+    version of the file(s), but you are not obligated to do so.  If you
+    do not wish to do so, delete this exception statement from your
+    version.  If you delete this exception statement from all source
+    files in the program, then also delete it here.
 */
 
 /** @file  src/cpl.h
@@ -37,7 +51,7 @@
 
 namespace dcp {
 
-class ReelAsset;
+class ReelMXF;
 class Reel;
 class XMLMetadata;
 class MXFMetadata;
@@ -51,7 +65,7 @@ class CPL : public Asset
 {
 public:
        CPL (std::string annotation_text, ContentKind content_kind);
-       CPL (boost::filesystem::path file);
+       explicit CPL (boost::filesystem::path file);
 
        bool equals (
                boost::shared_ptr<const Asset> other,
@@ -64,7 +78,11 @@ public:
 
        /** @return contents of the &lt;AnnotationText&gt; node */
        std::string annotation_text () const {
-               return _annotation_text;
+               return _metadata.annotation_text;
+       }
+
+       void set_annotation_text (std::string at) {
+               _metadata.annotation_text = at;
        }
 
        /** @return contents of the &lt;ContentTitleText&gt; node */
@@ -72,6 +90,10 @@ public:
                return _content_title_text;
        }
 
+       void set_content_title_text (std::string ct) {
+               _content_title_text = ct;
+       }
+
        /** @return contents of the &lt;Id&gt; node within &lt;ContentVersion&gt; */
        void set_content_version_id (std::string id) {
                _content_version_id = id;
@@ -94,9 +116,10 @@ public:
                return _reels;
        }
 
/** @return the ReelAssets in this CPL in all reels.
         */
-       std::list<boost::shared_ptr<const ReelAsset> > reel_assets () const;
+       std::list<boost::shared_ptr<const ReelMXF> > reel_mxfs () const;
+       std::list<boost::shared_ptr<ReelMXF> > reel_mxfs ();
 
        bool encrypted () const;
 
@@ -118,14 +141,27 @@ public:
                return _standard;
        }
 
+       std::list<Rating> ratings () const {
+               return _ratings;
+       }
+
+       void set_ratings (std::list<Rating> r) {
+               _ratings = r;
+       }
+
+       std::string content_version_label_text () const {
+               return _content_version_label_text;
+       }
+
+       static std::string static_pkl_type (Standard standard);
+
 protected:
        /** @return type string for PKLs for this asset */
        std::string pkl_type (Standard standard) const;
 
 private:
-       std::string _annotation_text;               ///< &lt;AnnotationText&gt;
-       /** &lt;Issuer&gt;, &lt;Creator&gt; and &lt;IssueDate&gt;.  These are grouped
-        *  because they occur together in a few places.
+       /** &lt;Issuer&gt;, &lt;Creator&gt;, &lt;IssueDate&gt; and &lt;AnnotationText&gt.
+        *  These are grouped because they occur together in a few places.
         */
        XMLMetadata _metadata;
        std::string _content_title_text;            ///< &lt;ContentTitleText&gt;
@@ -133,6 +169,7 @@ private:
        std::string _content_version_id;            ///< &lt;Id&gt; in &lt;ContentVersion&gt;
        std::string _content_version_label_text;    ///< &lt;LabelText&gt; in &lt;ContentVersion&gt;
        std::list<boost::shared_ptr<Reel> > _reels;
+       std::list<Rating> _ratings;
 
        /** Standard of CPL that was read in */
        boost::optional<Standard> _standard;
@@ -94,9 +116,10 @@ public:
        }
 
-       /** @return the ReelAssets in this CPL in all reels.
+       /** @return the ReelMXFs in this CPL in all reels.
         */